==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/read.pfizer.Listing.R <==
read.pfizer.Listing <- function(file, verbose=TRUE)
  {

    standardColFormats <- c("Locus"="",
                            "Gene Marker"="",
                            "Locus Start"=1,
                            "Sample ID"="",
                            "Donor ID"="",
                            "Project"="",
                            "Protocol"="",
                            "Genotype"="")
    standardCols <- names(standardColFormats)

    ## line one: Column Names
    header <- scan(file, what="", nlines=1, sep=",", quiet=TRUE)
    nonempty <- (header > ", ") & (!is.na(header))

    if(!all(standardCols %in% header))
      stop("Data file does not match standard for Pfizer",
           " `Listings, By Sample ID' format.")

    ## Read the file data
    formats <- c(standardColFormats,
                 rep("", length(header)-length(standardColFormats)))
    
    fileData <- scan(file, what=formats, skip=1, sep=",", quiet=TRUE)
    fileData <- matrix(fileData, ncol=length(header), byrow=TRUE)
    dframe <- as.data.frame(fileData)
    colnames(dframe) <- colnames(fileData) <- header

    wideData <- reshape(
                        dframe[,-c(1,3)], 
                        v.names="Genotype",
                        idvar="Sample ID",
                        timevar="Gene Marker",
                        direction="wide"
                        )

    markerNames <- levels(dframe$"Gene Marker")
    markerColFlag <- grep("Genotype\\.", colnames(wideData))
    colnames(wideData)[markerColFlag] <- markerNames
    
    extraCols <- header[ !(header %in% standardCols ) ]

    phenoCols <- c("Sample ID", "Donor ID", extraCols)
    genoCols  <- markerNames
    studyCols <- c("Project","Protocol")

    if(verbose)
      {
        nGenes <- nlevels( dframe$Locus )
        nmarkers <- nlevels( dframe$"Gene Marker")
        nSamples <- nrow(wideData)


        cat(
            "\n",
            "Read ", 1+nrow(fileData), " lines containing ",
            nmarkers, " Markers from ",
            nGenes,   " Genes on ",
            nSamples, " Samples.\n\n",
            sep=""
            )
      }

    dupFlag <- duplicated(wideData$"Donor ID")
    dupList <- unique(wideData$"Donor ID"[dupFlag])
    if(length(dupList)>0)
      warning("More than one sample for Donor ID(s): ",
              paste('"', dupList, '"',sep="",collapse=", "))


    genotypeInfo <-  wideData[,genoCols, drop=FALSE]
    phenotypeInfo <-  wideData[,phenoCols, drop=FALSE]
    rownames(genotypeInfo)  <- as.character(wideData[,"Sample ID"])
    rownames(phenotypeInfo) <- as.character(wideData[,"Sample ID"])

    markerInfo <-  unique(dframe[,1:3])

    colnames(markerInfo) <- c("Gene","Marker","Position")

    retval <- list(
                   genotypeInfo =genotypeInfo,
                   phenotypeInfo=phenotypeInfo,
                   markerInfo=markerInfo,
                   studyInfo =as.list(fileData[1,studyCols])
                   )

    retval
  }

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/read.pfizer.Listing.R <==
read.pfizer.Listing <- function(file, verbose=TRUE)
  {

    standardColFormats <- c("Locus"="",
                            "Gene Marker"="",
                            "Locus Start"=1,
                            "Sample ID"="",
                            "Donor ID"="",
                            "Project"="",
                            "Protocol"="",
                            "Genotype"="")
    standardCols <- names(standardColFormats)

    ## line one: Column Names
    header <- scan(file, what="", nlines=1, sep=",", quiet=TRUE)
    nonempty <- (header > ", ") & (!is.na(header))

    if(!all(standardCols %in% header))
      stop("Data file does not match standard for Pfizer",
           " `Listings, By Sample ID' format.")

    ## Read the file data
    formats <- c(standardColFormats,
                 rep("", length(header)-length(standardColFormats)))
    
    fileData <- scan(file, what=formats, skip=1, sep=",", quiet=TRUE)
    fileData <- matrix(fileData, ncol=length(header), byrow=TRUE)
    dframe <- as.data.frame(fileData)
    colnames(dframe) <- colnames(fileData) <- header

    wideData <- reshape(
                        dframe[,-c(1,3),drop=FALSE], 
                        v.names="Genotype",
                        idvar="Sample ID",
                        timevar="Gene Marker",
                        direction="wide"
                        )

    markerNames <- levels(dframe$"Gene Marker")
    markerColFlag <- grep("Genotype\\.", colnames(wideData))
    colnames(wideData)[markerColFlag] <- markerNames
    
    extraCols <- header[ !(header %in% standardCols ) ]

    phenoCols <- c("Sample ID", "Donor ID", extraCols)
    genoCols  <- markerNames
    studyCols <- c("Project","Protocol")

    if(verbose)
      {
        nGenes <- nlevels( dframe$Locus )
        nMarkers <- nlevels( dframe$"Gene Marker")
        nSamples <- nrow(wideData)


        cat(
            "\n",
            "Read ", 1+nrow(fileData), " lines containing ",
            nMarkers, " Markers from ",
            nGenes,   " Genes on ",
            nSamples, " Samples.\n\n",
            sep=""
            )
      }

    dupFlag <- duplicated(wideData$"Donor ID")
    dupList <- unique(wideData$"Donor ID"[dupFlag])
    if(length(dupList)>0)
      warning("More than one sample for Donor ID(s): ",
              paste('"', dupList, '"',sep="",collapse=", "))


    genotypeInfo <-  wideData[,genoCols, drop=FALSE]
    phenotypeInfo <-  wideData[,phenoCols, drop=FALSE]
    rownames(genotypeInfo)  <- as.character(wideData[,"Sample ID"])
    rownames(phenotypeInfo) <- as.character(wideData[,"Sample ID"])

    markerInfo <-  unique(dframe[,1:3,drop=FALSE])

    colnames(markerInfo) <- c("Gene","Marker","Position")

    retval <- list(
                   genotypeInfo =genotypeInfo,
                   phenotypeInfo=phenotypeInfo,
                   markerInfo=markerInfo,
                   studyInfo =as.list(fileData[1,studyCols])
                   )

    retval
  }
